@@ -14,6 +14,15 @@
 //! This crate is part of
 //! [Arti](https://gitlab.torproject.org/tpo/core/arti/), a project to
 //! implement [Tor](https://www.torproject.org/) in Rust.
+//!
+//! # Features
+//!
+//! `xz` -- enable XZ compression.  This can be expensive in RAM and CPU,
+//! but it saves a lot of bandwidth.  (On by default.)
+//!
+//! `zstd` -- enable ZSTD compression.  (On by default.)
+//!
+//! `routerdesc` -- Add support for downloading router descriptors.
 
 #![deny(missing_docs)]
 #![warn(noop_method_call)]
@@ -39,6 +48,7 @@
 #![warn(clippy::option_option)]
 #![warn(clippy::rc_buffer)]
 #![deny(clippy::ref_option_ref)]
+#![warn(clippy::semicolon_if_nothing_returned)]
 #![warn(clippy::trait_duplication_in_bounds)]
 #![deny(clippy::unnecessary_wraps)]
 #![warn(clippy::unseparated_literal_suffix)]
@@ -387,7 +397,7 @@ where
     }
 }
 
-/// Helper: Return a boxed decoder object that wrapsthe stream  $s.
+/// Helper: Return a boxed decoder object that wraps the stream  $s.
 macro_rules! decoder {
     ($dec:ident, $s:expr) => {{
         let mut decoder = $dec::new($s);
@@ -471,7 +481,7 @@ mod test {
     }
 
     #[async_test]
-    async fn decomp_identity() -> Result<()> {
+    async fn decompress_identity() -> Result<()> {
         let mut text = Vec::new();
         for _ in 0..1000 {
             text.extend(b"This is a string with a nontrivial length that we'll use to make sure that the loop is executed more than once.");
@@ -576,7 +586,7 @@ mod test {
         let (mut s2_r, mut s2_w) = s2.split();
         let mock_time = MockSleepProvider::new(std::time::SystemTime::now());
 
-        let req = request::RouterDescRequest::all();
+        let req: request::MicrodescRequest = vec![[9; 32]].into_iter().collect();
 
         let (v1, v2, v3): (Result<DirResponse>, Result<Vec<u8>>, Result<()>) = futures::join!(
             async {
@@ -601,7 +611,9 @@ mod test {
         v3?;
         let request = v2?;
 
-        assert!(request[..].starts_with(b"GET /tor/server/all.z HTTP/1.0\r\n"));
+        assert!(request[..].starts_with(
+            b"GET /tor/micro/d/CQkJCQkJCQkJCQkJCQkJCQkJCQkJCQkJCQkJCQkJCQk.z HTTP/1.0\r\n"
+        ));
         assert_eq!(response.status_code(), 200);
         assert!(!response.is_partial());
         assert!(response.error().is_none());
